package RapidApp::Error::UserError;

use strict;
use warnings;

die "Use RapidApp::Responder::UserError instead of RapidApp::Error::UserError";

1;